#!/usr/bin/env python
'''blast-GOfreq,psiblast-GOfreq,combine-GOfreq vs seqID cutoff'''
import matplotlib
matplotlib.use("agg")
matplotlib.rcParams['figure.figsize'] = (6, 8)
from matplotlib import pylab as plt
import numpy as np

seqID_list=[0.2,0.3,0.5,0.9]
seqID_list=[0.2,0.3,0.5]
dataset={
    'MetaGO':{
        'MF':[0.4541,0.4874,0.5184,0.5459],
        'BP':[0.3909,0.4076,0.4281,0.4504],
        'CC':[0.5894,0.5977,0.6046,0.6125],
    },
    'structure':{
        'MF':[0.3083,0.3090,0.3079,0.3079],
        'BP':[0.2539,0.2544,0.2534,0.2534],
        'CC':[0.4375,0.4375,0.4375,0.4375],
    },

    'sequence':{
        'MF':[0.3572,0.4499,0.5210,0.5747],
        'BP':[0.2728,0.3438,0.3956,0.4481],
        'CC':[0.4197,0.4987,0.5556,0.6050],
    },

    'PPIhomo':{ # PPI for now
        'MF':[0.3349,0.3371,0.3380,0.3384],
        'BP':[0.3851,0.3855,0.3861,0.3863],
        'CC':[0.5606,0.5610,0.5612,0.5614],
    },
    'GoFDR':{
        'MF':[0.3029,0.3989,0.4747,0.5824],
        'BP':[0.2435,0.3229,0.3847,0.5119],
        'CC':[0.3820,0.4775,0.5414,0.6323],
    },

    'PSIBLAST':{
        'MF':[0.2362,0.2921,0.4142,0.5294],
        'BP':[0.1671,0.2018,0.2854,0.4011],
        'CC':[0.2904,0.3357,0.4344,0.5356],
    },
    'BLAST':{
        'MF':[0.0034,0.2723,0.3865,0.5100],
        'BP':[0.0048,0.1806,0.2349,0.3776],
        'CC':[0.0047,0.3043,0.4002,0.5273],
    },
    'Naive':{
        'MF':[0.1786]*len(seqID_list),
        'BP':[0.2674]*len(seqID_list),
        'CC':[0.4808]*len(seqID_list),
    },
}

method_list=["MetaGO","structure","sequence","PPIhomo","GoFDR","PSIBLAST","BLAST","Naive"]
method_dict={
    "MetaGO":"MetaGO",
    "structure":"structure component of MetaGO",
    "sequence" :"sequence component of MetaGO",
    "PPIhomo"  :"PPI homolog component of MetaGO",
    "GoFDR":"GoFDR",
    "PSIBLAST":"PSIBLAST",
    "BLAST":"BLAST",
    "Naive":"Naive"}

marker_list=[
    'o',
    'v',
    '^',
    'D', # PPIhomo
    '<',
    '>',
    's',
    '', # Naive
    '8',
    'p',
    'h',
    'H',
    'D',
    '*',
]

linestyle=["-",":",":",":","-","-","-","-"]

color_list=[
    'k', # MetaGO
    'r', # structure
    'b', # sequence
    'g', # PPIhomo
    'm', # GoFDR
    'c', # PISBLAST
    'y', # BLAST
    '0.5', # Naive
]
lw=2

Aspect_list=["MF","BP","CC"]
namespace_dict={'MF':"Molecular Function",'BP':"Biological Process",'CC':"Cellular Component"}

ind=np.arange(len(seqID_list))/(1.*len(seqID_list))
width = 1./(len(seqID_list)*(2+len(method_list)))  # the width of the bars
ymax=0.62

def cm2inch(value):
    return value/2.54

fig=plt.figure()
fig_subplot,axes = plt.subplots(nrows=4, ncols=1)
fig_subplot.tight_layout()
#plt.subplots_adjust(wspace = 2)
for i,Aspect in enumerate(Aspect_list):
    plt.subplot(4,1,i+1)

    rects=[]
    for m,method in enumerate(method_list):
        rects.append(plt.bar(ind+(1+m)*width, 
            dataset[method][Aspect][:len(seqID_list)],
            .9*width, #hatch=hatch_list[m]*2,
            color=color_list[m],edgecolor=''))
        for idx in range(len(seqID_list)):
            if marker_list[m]:
                y=np.arange(dataset[method][Aspect][idx]-0.05,0,-0.1)
                x=[ind[idx]+(1.5+m)*width]*len(y)
                plt.plot(x,y,marker_list[m],
                    markerfacecolor="white",
                    markeredgewidth=0,
                    markersize=4,
                    markeredgecolor=None)
            if m==0:
                y=[dataset[method][Aspect][idx]]*2
                x=[1.*idx/len(seqID_list),1.*(1+idx)/len(seqID_list)]
                plt.plot(x,y,':',lw=2,color=color_list[m])
            
    for x in np.arange(1./len(seqID_list),1,1./len(seqID_list)):
        plt.plot([x,x],[0,ymax],'k--')
    plt.title(Aspect)
    plt.axis([0,1,0,ymax])
    plt.xlabel("sequence identity cutoff")
    plt.ylabel("Fmax")
    plt.gca().axes.get_xaxis().set_ticks(
        (np.arange(len(seqID_list))+0.5)/(1.*len(seqID_list)) )
    plt.gca().axes.get_xaxis().set_ticklabels(
        ["%.1f"%s for s in seqID_list])



ax=plt.subplot(4,1,4)
rects=[]
ind=np.arange(0,1.,1./len(method_list))
for m in range(len(method_list)):
    x_coor=0.25+0.3*(m>=len(method_list)/2)
    y_coor=-width*(2*m % len(method_list)+1)

    ax.add_patch(matplotlib.patches.Rectangle(
        [x_coor, y_coor],0.09,width,
        edgecolor=None, facecolor=color_list[m], linewidth=0)
    )
    if marker_list[m]:
        x=np.arange(x_coor+0.01,x_coor+0.1,0.03)
        y=[y_coor+width/2.]*len(x)
        plt.plot(x,y,marker_list[m],
            markerfacecolor="white",
            markeredgewidth=0,
            markersize=4,
            markeredgecolor=None)

    plt.text(0.1+x_coor,y_coor, method_list[m])

plt.axis([0,1,-1.5*width*len(method_list),0])
plt.gca().axes.get_xaxis().set_visible(False)
plt.gca().axes.get_yaxis().set_visible(False)
for border in ["left","right","top","bottom"]:
    ax.spines[border].set_visible(False)
#lg=plt.legend(loc="upper center",fontsize=11,ncol=2)
#lg.draw_frame(False)
pl=plt.plot([0.5,0.5],[0.5,0.5], "ws", mec="w",mew=1)


#plt.tight_layout(pad=0.4, w_pad=0.5, h_pad=1.0)
plt.tight_layout()
for outfmt in ["png","eps","svg"]:
    plt.savefig("plotseqID."+outfmt,dpi=350)
plt.close()
