#!/usr/bin/env python
'''blast-GOfreq,psiblast-GOfreq,combine-GOfreq vs seqID cutoff'''
import matplotlib
matplotlib.use("agg")
matplotlib.rcParams['figure.figsize'] = (6, 8)
from matplotlib import pylab as plt
import numpy as np

seqID_list=  [   0.2,   0.3,   0.5,   0.9]
seqID_list=  [   0.2,   0.3,   0.5]
dataset={
    'BLAST-localID':{
        'MF':[0.0034,0.2723,0.3865,0.5100],
        'BP':[0.0048,0.1806,0.2349,0.3776],
        'CC':[0.0047,0.3043,0.4002,0.5273],
    },
    'BLAST-globalID':{
        'MF':[0.0034,0.2716,0.3983,0.5284],
        'BP':[0.0048,0.1789,0.2836,0.4215],
        'CC':[0.0047,0.3025,0.4325,0.5511],
    },
    'BLAST-evalue':{
        'MF':[0.0005,0.1010,0.1333,0.1439],
        'BP':[0.0008,0.0632,0.0821,0.1050],
        'CC':[0.0020,0.1090,0.1575,0.1666],
    },
    'BLAST-frequency':{
        'MF':[0.0034,0.3694,0.5058,0.5597],
        'BP':[0.0048,0.2514,0.3764,0.4317],
        'CC':[0.0047,0.3693,0.5348,0.5872],
    },

    'PSIBLAST-localID':{
        'MF':[0.2362,0.2921,0.4142,0.5294],
        'BP':[0.1671,0.2018,0.2854,0.4011],
        'CC':[0.2904,0.3357,0.4344,0.5356],
    },
    'PSIBLAST-globalID':{
        'MF':[0.2633,0.3265,0.4325,0.5281],
        'BP':[0.1758,0.2123,0.3137,0.4192],
        'CC':[0.2938,0.3562,0.4589,0.5517],
    },
    'PSIBLAST-evalue':{
        'MF':[0.1427,0.1130,0.1350,0.1335],
        'BP':[0.0932,0.0733,0.0919,0.0941],
        'CC':[0.1818,0.1382,0.1733,0.1700],
    },
    'PSIBLAST-frequency':{
        'MF':[0.3556,0.4370,0.4884,0.5206],
        'BP':[0.2729,0.3382,0.3835,0.4129],
        'CC':[0.4168,0.4861,0.5377,0.5693],
    },

    'sequence':{
        'MF':[0.3572,0.4499,0.5210,0.5747],
        'BP':[0.2728,0.3438,0.3956,0.4481],
        'CC':[0.4197,0.4987,0.5556,0.6050],
    },
}

method_list=[
    "BLAST-localID",   "BLAST-globalID",   "BLAST-evalue",   "BLAST-frequency",
    "PSIBLAST-localID","PSIBLAST-globalID","PSIBLAST-evalue","PSIBLAST-frequency",
    "sequence",
    ]
method_list=[
    "PSIBLAST-localID","PSIBLAST-globalID","PSIBLAST-evalue","PSIBLAST-frequency",
    "BLAST-localID",   "BLAST-globalID",   "BLAST-evalue",   "BLAST-frequency",
    "sequence",
    ]
method_dict={
    "MetaGO":"MetaGO",
    "structure":"structure component of MetaGO",
    "sequence" :"sequence component of MetaGO",
    "PPIhomo"  :"PPI homolog component of MetaGO",
    "GoFDR":"GoFDR",
    "PSIBLAST":"PSIBLAST",
    "BLAST":"BLAST",
    "Naive":"Naive"}

hatch_list=[
    '',
    '/',
    '\\',
    'x',

    '',
    '/',
    '\\',
    'x',

    '',
]

linestyle=["-",":",":",":","-","-","-","-"]

color_list=[
    'c', # PISBLAST
    'c', # PISBLAST
    'c', # PISBLAST
    'c', # PISBLAST
    'y', # BLAST
    'y', # BLAST
    'y', # BLAST
    'y', # BLAST
    'b', # sequence
]
lw=2

Aspect_list=["MF","BP","CC"]
namespace_dict={'MF':"Molecular Function",'BP':"Biological Process",'CC':"Cellular Component"}

ind=np.arange(len(seqID_list))/(1.*len(seqID_list))
width = 1./(len(seqID_list)*(2+len(method_list)))  # the width of the bars
ymax=0.62

def cm2inch(value):
    return value/2.54

fig=plt.figure()
fig_subplot,axes = plt.subplots(nrows=4, ncols=1)
fig_subplot.tight_layout()
#plt.subplots_adjust(wspace = 2)
for i,Aspect in enumerate(Aspect_list):
    plt.subplot(4,1,i+1)

    rects=[]
    for m,method in enumerate(method_list):
        rects.append(plt.bar(ind+(1+m)*width, 
            dataset[method][Aspect][:len(seqID_list)],
            .9*width, hatch=hatch_list[m]*2,color=color_list[m],edgecolor=''))
    for x in np.arange(1./len(seqID_list),1,1./len(seqID_list)):
        plt.plot([x,x],[0,ymax],'k--')
    plt.title(Aspect)
    plt.axis([0,1,0,ymax])
    plt.xlabel("sequence identity cutoff")
    plt.ylabel("Fmax")
    plt.gca().axes.get_xaxis().set_ticks(
        (np.arange(len(seqID_list))+0.5)/(1.*len(seqID_list)) )
    plt.gca().axes.get_xaxis().set_ticklabels(
        ["%.1f"%s for s in seqID_list])



ax=plt.subplot(4,1,4)
for m in range(len(method_list)):
    rects.append(plt.bar(0.5, 0, .9*width, label=method_list[m],
        hatch=hatch_list[m]*2,color=color_list[m],edgecolor=''))
## dummy bar
rects.append(plt.bar(0.5, 0, .9*width, label=' ',
    hatch='',color='w',edgecolor=''))
rects.append(plt.bar(0.5, 0, .9*width, label=' ',
    hatch='',color='w',edgecolor=''))

plt.axis([0,1,0,1])
plt.gca().axes.get_xaxis().set_visible(False)
plt.gca().axes.get_yaxis().set_visible(False)
for border in ["left","right","top","bottom"]:
    ax.spines[border].set_visible(False)
lg=plt.legend(loc="upper right",fontsize=11,ncol=3)
lg.draw_frame(False)
pl=plt.plot([0.5,0.5],[0.5,0.5], "ws", mec="w",mew=1)


#plt.tight_layout(pad=0.4, w_pad=0.5, h_pad=1.0)
plt.tight_layout()
for outfmt in ["png","eps","svg"]:
    plt.savefig("plotseqID_baseline."+outfmt,dpi=350)
plt.close()
