#!/usr/bin/env python
'''blast-GOfreq,psiblast-GOfreq,combine-GOfreq vs seqID cutoff'''
import matplotlib
matplotlib.use("agg")
matplotlib.rcParams['figure.figsize'] = (6, 8)
from matplotlib import pylab as plt
import numpy as np

seqID_list=[0.2,0.3,0.5,0.9]
dataset={
    'BLAST-localID':{
        'MF':[0.0192,0.3787,0.4812,0.5496],
        'BP':[0.0147,0.2656,0.3644,0.5026],
        'CC':[0.0136,0.2880,0.3437,0.4282],
    },
    'BLAST-globalID':{
        'MF':[0.0192,0.3771,0.4891,0.5530],
        'BP':[0.0147,0.2768,0.3809,0.5133],
        'CC':[0.0136,0.2904,0.3493,0.4315],
    },
    'BLAST-evalue':{
        'MF':[0.0192,0.3781,0.4891,0.5459],
        'BP':[0.0147,0.2841,0.3405,0.4121],
        'CC':[0.0136,0.2722,0.2868,0.3267],
    },
    'BLAST-frequency':{
        'MF':[0.0192,0.4681,0.5782,0.5962],
        'BP':[0.0147,0.4162,0.5288,0.5555],
        'CC':[0.0136,0.4269,0.5464,0.5556],
    },

    'PSIBLAST-localID':{
        'MF':[0.3315,0.4021,0.4829,0.5482],
        'BP':[0.2424,0.2942,0.3773,0.4971],
        'CC':[0.2672,0.3159,0.3436,0.4297],
    },
    'PSIBLAST-globalID':{
        'MF':[0.3182,0.4155,0.4906,0.5517],
        'BP':[0.2433,0.3115,0.3904,0.5099],
        'CC':[0.2598,0.3124,0.3480,0.4291],
    },
    'PSIBLAST-evalue':{
        'MF':[0.3318,0.3894,0.4220,0.4433],
        'BP':[0.2224,0.2474,0.2709,0.2997],
        'CC':[0.2442,0.2559,0.2649,0.2714],
    },
    'PSIBLAST-frequency':{
        'MF':[0.4353,0.5196,0.5674,0.5776],
        'BP':[0.3838,0.4647,0.5111,0.5265],
        'CC':[0.4233,0.5336,0.5649,0.5700],
    },

    'sequence':{
        'MF':[0.4353,0.5308,0.5978,0.6169],
        'BP':[0.3872,0.4787,0.5401,0.5683],
        'CC':[0.4229,0.5334,0.5717,0.5856],
    },
}

method_list=[
    "BLAST-localID",   "BLAST-globalID",   "BLAST-evalue",   "BLAST-frequency",
    "PSIBLAST-localID","PSIBLAST-globalID","PSIBLAST-evalue","PSIBLAST-frequency",
    "sequence",
    ]
method_list=[
    "PSIBLAST-localID","PSIBLAST-globalID","PSIBLAST-evalue","PSIBLAST-frequency",
    "BLAST-localID",   "BLAST-globalID",   "BLAST-evalue",   "BLAST-frequency",
    "sequence",
    ]
method_dict={
    "MetaGO":"MetaGO",
    "structure":"structure component of MetaGO",
    "sequence" :"sequence component of MetaGO",
    "PPIhomo"  :"PPI homolog component of MetaGO",
    "GoFDR":"GoFDR",
    "PSIBLAST":"PSIBLAST",
    "BLAST":"BLAST",
    "Naive":"Naive"}

hatch_list=[
    '',
    '/',
    '\\',
    'x',

    '',
    '/',
    '\\',
    'x',

    '',
]

linestyle=["-",":",":",":","-","-","-","-"]

color_list=[
    'c', # PISBLAST
    'c', # PISBLAST
    'c', # PISBLAST
    'c', # PISBLAST
    'y', # BLAST
    'y', # BLAST
    'y', # BLAST
    'y', # BLAST
    'b', # sequence
]
lw=2

Aspect_list=["MF","BP","CC"]
namespace_dict={'MF':"Molecular Function",'BP':"Biological Process",'CC':"Cellular Component"}

ind=np.arange(len(seqID_list))/(1.*len(seqID_list))
width = 0.023       # the width of the bars

def cm2inch(value):
    return value/2.54

fig=plt.figure()
fig_subplot,axes = plt.subplots(nrows=4, ncols=1)
fig_subplot.tight_layout()
#plt.subplots_adjust(wspace = 2)
for i,Aspect in enumerate(Aspect_list):
    plt.subplot(4,1,i+1)

    rects=[]
    for m,method in enumerate(method_list):
        rects.append(plt.bar(ind+(1+m)*width, 
            dataset[method][Aspect], .9*width,
            hatch=hatch_list[m]*2,color=color_list[m],edgecolor=''))
    plt.title(Aspect)
    plt.axis([0,1,0,0.7])
    plt.xlabel("sequence identity cutoff")
    plt.ylabel("Fmax")
    plt.gca().axes.get_xaxis().set_ticks(
        (np.arange(len(seqID_list))+0.5)/(1.*len(seqID_list)) )
    plt.gca().axes.get_xaxis().set_ticklabels(
        ["%.1f"%s for s in seqID_list])



ax=plt.subplot(4,1,4)
for m in range(len(method_list)):
    rects.append(plt.bar(0.5, 0, .9*width, label=method_list[m],
        hatch=hatch_list[m]*2,color=color_list[m],edgecolor=''))
## dummy bar
rects.append(plt.bar(0.5, 0, .9*width, label=' ',
    hatch='',color='w',edgecolor=''))
rects.append(plt.bar(0.5, 0, .9*width, label=' ',
    hatch='',color='w',edgecolor=''))

plt.axis([0,1,0,1])
plt.gca().axes.get_xaxis().set_visible(False)
plt.gca().axes.get_yaxis().set_visible(False)
for border in ["left","right","top","bottom"]:
    ax.spines[border].set_visible(False)
lg=plt.legend(loc="upper right",fontsize=11,ncol=3)
lg.draw_frame(False)
pl=plt.plot([0.5,0.5],[0.5,0.5], "ws", mec="w",mew=1)


#plt.tight_layout(pad=0.4, w_pad=0.5, h_pad=1.0)
plt.tight_layout()
for outfmt in ["png","eps","svg"]:
    plt.savefig("plotseqID_baseline."+outfmt,dpi=350)
plt.close()
